@@ -5,7 +5,7 @@ del get_versions
 
 from .manager.comms import ZMQCommSendAsync, ZMQCommSendThreads, CommTimeoutError  # noqa: E402, F401
 from .manager.annotation_decorator import parameter_annotation_decorator  # noqa: E402, F401
-from .manager.output_streaming import ReceiveConsoleOutput  # noqa: E402, F401
+from .manager.output_streaming import ReceiveConsoleOutput, ReceiveConsoleOutputAsync  # noqa: E402, F401
 
 from .manager.profile_ops import validate_plan  # noqa: E402, F401
 from .manager.profile_ops import bind_plan_arguments  # noqa: E402, F401
