@@ -93,7 +93,7 @@ _simple_annotation_with_default = {
         "val_arg": {
             "description": "Parameter 'val_arg'",
             "annotation": "int",
-            "default": "10",
+            "default": 10,
         },
         "val_kwarg": {
             "description": "Parameter 'val_kwarg'",
@@ -101,7 +101,7 @@ _simple_annotation_with_default = {
             "enums": {
                 "CustomEnum": ("p1", "p2", "p3"),
             },
-            "default": "'p1'",  # String value should be quoted
+            "default": "p1",  # String value should be quoted
         },
     },
 }
@@ -111,10 +111,10 @@ _simple_annotation_with_min_max_step = {
     "parameters": {
         "val_arg": {
             "description": "Parameter 'val_arg'",
-            "default": "10",
-            "min": "1",
-            "max": "100",
-            "step": "0.1",
+            "default": 10,
+            "min": 1,
+            "max": 100,
+            "step": 0.1,
         },
     },
 }
@@ -414,21 +414,6 @@ _trivial_annotation_error6 = {
 }
 
 
-_trivial_annotation_error7 = {
-    "description": "Example of annotation with varargs and varkwargs.",
-    "parameters": {
-        "existing_param": {
-            "description": "Required key is 'discription'. Schema validation should fail.",
-            "annotation": "Motor",
-            "devices": {
-                "Motor": ["abcde"],
-            },
-            "default": 50,  # Must be a string ('50', not just 50)
-        }
-    },
-}
-
-
 # fmt: off
 @pytest.mark.parametrize("custom_annotation, ex_type, err_msg", [
     (_trivial_annotation_error1, jsonschema.ValidationError,
@@ -440,7 +425,6 @@ _trivial_annotation_error7 = {
      r"Additional properties are not allowed \('some_devices' was unexpected\)"),
     (_trivial_annotation_error5, jsonschema.ValidationError, "is not of type 'string'"),
     (_trivial_annotation_error6, jsonschema.ValidationError, "is not of type 'array'"),
-    (_trivial_annotation_error7, jsonschema.ValidationError, "50 is not of type 'string'"),
 ])
 # fmt: on
 def test_annotation_dectorator_8_fail(custom_annotation, ex_type, err_msg):
