@@ -274,7 +274,14 @@ class RunEngineWorker(Process):
         """
         item_uid = self._state["running_plan"]["item_uid"] if self._state["running_plan"] else None
         plan_completed = self._state["running_plan_completed"]
+        # TODO: replace RE._state with RE.state property in the worker code (improve code style).
         re_state = str(self._RE._state) if self._RE else "null"
+        try:
+            re_deferred_pause_requested = self._RE.deferred_pause_requested if self._RE else False
+        except AttributeError:
+            # TODO: delete this branch once Bluesky supporting
+            #   ``RunEngine.deferred_pause_pending``` is widely deployed.
+            re_deferred_pause_requested = self._RE._deferred_pause_requested if self._RE else False
         env_state = self._state["environment_state"]
         re_report_available = self._re_report is not None
         run_list_updated = self._active_run_list.is_changed()  # True - updates are available
@@ -283,6 +290,7 @@ class RunEngineWorker(Process):
             "running_plan_completed": plan_completed,
             "re_report_available": re_report_available,
             "re_state": re_state,
+            "re_deferred_pause_requested": re_deferred_pause_requested,
             "environment_state": env_state,
             "run_list_updated": run_list_updated,
         }
@@ -296,8 +304,9 @@ class RunEngineWorker(Process):
         it is read.
         """
         # TODO: may be report should be cleared only after the reset? Check the logic.
-        msg_out = self._re_report
-        self._re_report = None
+        with self._re_report_lock:
+            msg_out = self._re_report
+            self._re_report = None
         return msg_out
 
     def _request_run_list_handler(self):
@@ -476,8 +485,8 @@ class RunEngineWorker(Process):
         """
         # This function blocks the main thread
         while True:
-            # Polling once per second. This is fast enough for slowly executed plans.
-            ttime.sleep(1)
+            # Polling 10 times per second. This is fast enough for slowly executed plans.
+            ttime.sleep(0.1)
             # Exit the thread if the Event is set (necessary to gracefully close the process)
             if self._exit_event.is_set():
                 break
